<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

if ( ! function_exists( 'legit_news_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Legit News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function legit_news_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'legit_news_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'legit_news_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Legit News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function legit_news_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'legit_news_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'legit_news_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Legit News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function legit_news_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'legit_news_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[topbar_section_enable]' )->value() );
}

/****************************Breaking News****************************************** */
/**
 * Check if Breaking News section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_breaking_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[breaking_news_section_enable]' )->value() );
}

/**
 * Check if Breaking News section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_breaking_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[breaking_news_content_type]' )->value();
	return legit_news_pro_is_breaking_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Breaking News section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_breaking_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[breaking_news_content_type]' )->value();
	return legit_news_pro_is_breaking_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if Breaking News section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_breaking_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[breaking_news_content_type]' )->value();
	return legit_news_pro_is_breaking_news_section_enable( $control ) && ( 'post' == $content_type );
}

/****************************Hero Post****************************************** */

/**
 * Check if hero_post section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_hero_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[hero_post_section_enable]' )->value() );
}

/**
 * Check if hero_post section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_hero_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[hero_post_content_type]' )->value();
	return legit_news_pro_is_hero_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if hero_post section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_hero_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[hero_post_content_type]' )->value();
	return legit_news_pro_is_hero_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero_post section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_hero_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[hero_post_content_type]' )->value();
	return legit_news_pro_is_hero_post_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if must_read section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_must_read_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[must_read_section_enable]' )->value() );
}

/**
 * Check if must_read section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_must_read_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[must_read_content_type]' )->value();
	return legit_news_pro_is_must_read_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if must_read section content type is recent.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_must_read_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[must_read_content_type]' )->value();
	return legit_news_pro_is_must_read_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if must_read section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_must_read_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[must_read_content_type]' )->value();
	return legit_news_pro_is_must_read_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if must_read section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_must_read_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[must_read_content_type]' )->value();
	return legit_news_pro_is_must_read_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if trending_news section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_trending_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[trending_news_section_enable]' )->value() );
}


/**
 * Check if fashion section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_fashion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[fashion_section_enable]' )->value() );
}

/**
 * Check if fashion section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_fashion_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[fashion_content_type]' )->value();
	return legit_news_pro_is_fashion_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if fashion section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_fashion_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[fashion_content_type]' )->value();
	return legit_news_pro_is_fashion_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if fashion section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_fashion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[fashion_content_type]' )->value();
	return legit_news_pro_is_fashion_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if photography section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_photography_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[photography_section_enable]' )->value() );
}

/**
 * Check if photography section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_photography_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[photography_content_type]' )->value();
	return legit_news_pro_is_photography_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if photography section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_photography_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[photography_content_type]' )->value();
	return legit_news_pro_is_photography_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if photography section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_photography_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[photography_content_type]' )->value();
	return legit_news_pro_is_photography_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if culture section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_culture_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[culture_section_enable]' )->value() );
}

/**
 * Check if culture section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_culture_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[culture_content_type]' )->value();
	return legit_news_pro_is_culture_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if culture section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_culture_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[culture_content_type]' )->value();
	return legit_news_pro_is_culture_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if culture section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_culture_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[culture_content_type]' )->value();
	return legit_news_pro_is_culture_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if single_column section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_single_column_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[single_column_section_enable]' )->value() );
}

/**
 * Check if single_column section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_single_column_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[single_column_content_type]' )->value();
	return legit_news_pro_is_single_column_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if single_column section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_single_column_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[single_column_content_type]' )->value();
	return legit_news_pro_is_single_column_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if single_column section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_single_column_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[single_column_content_type]' )->value();
	return legit_news_pro_is_single_column_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if related_post section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_related_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[related_post_section_enable]' )->value() );
}

/**
 * Check if related_post section content type is recent.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_related_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[related_post_content_type]' )->value();
	return legit_news_pro_is_related_post_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if related_post section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_related_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[related_post_content_type]' )->value();
	return legit_news_pro_is_related_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if related_post section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_related_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[related_post_content_type]' )->value();
	return legit_news_pro_is_related_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if related_post section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_related_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[related_post_content_type]' )->value();
	return legit_news_pro_is_related_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[about_content_type]' )->value();
	return legit_news_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[about_content_type]' )->value();
	return legit_news_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[about_content_type]' )->value();
	return legit_news_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[team_content_type]' )->value();
	return legit_news_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[team_content_type]' )->value();
	return legit_news_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[team_content_type]' )->value();
	return legit_news_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[blog_content_type]' )->value();
	return legit_news_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[blog_content_type]' )->value();
	return legit_news_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[blog_content_type]' )->value();
	return legit_news_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[blog_content_type]' )->value();
	return legit_news_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if slider section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[slider_content_type]' )->value();
	return legit_news_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[slider_content_type]' )->value();
	return legit_news_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[slider_content_type]' )->value();
	return legit_news_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is category.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[service_content_type]' )->value();
	return legit_news_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[service_content_type]' )->value();
	return legit_news_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'legit_news_pro_theme_options[service_content_type]' )->value();
	return legit_news_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if counter section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[counter_section_enable]' )->value() );
}
/**
 * Check if weather section is enabled.
 *
 * @since Legit News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function legit_news_pro_is_weather_section_enable( $control ) {
	return ( $control->manager->get_setting( 'legit_news_pro_theme_options[weather_section_enable]' )->value() );
}
