<?php
/**
 * Legit News Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function legit_news_pro_customize_register( $wp_customize ) {
	$options = legit_news_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'legit_news_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'legit_news_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'legit-news-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'legit_news_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'legit_news_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'legit-news-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'legit_news_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'legit_news_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'legit-news-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'legit-news-pro' ),
			'show-all'     => esc_html__( 'Show All', 'legit-news-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'legit-news-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'legit-news-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'legit-news-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'legit-news-pro' ),
			)
	) );

	$wp_customize->add_setting( 'legit_news_pro_theme_options[theme_version]', array(
		'default'           => $options['theme_version'],
		'sanitize_callback' => 'legit_news_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[theme_version]', array(
		'label'    => esc_html__( 'Theme Version', 'legit-news-pro' ),
		'type'    => 'radio',
		'section'  => 'colors',
		'choices'  => array(
            'dark-version'   	=> esc_html__( 'Dark Version', 'legit-news-pro' ),
            'lite-version'      => esc_html__( 'Lite Version', 'legit-news-pro' ),
		),
	) );


	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'legit_news_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'legit_news_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'legit-news-pro' ),
		'choices'  => array(
            'default'   => esc_html__( 'Default', 'legit-news-pro' ),
            'blue'      => esc_html__( 'Blue', 'legit-news-pro' ),
            'green'     => esc_html__( 'Green', 'legit-news-pro' ),
            'red'       => esc_html__( 'Red', 'legit-news-pro' ),
            'yellow'    => esc_html__( 'Yellow', 'legit-news-pro' ),
            'custom'    => esc_html__( 'Custom', 'legit-news-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'legit_news_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'legit_news_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',

	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'legit_news_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','legit-news-pro' ),
	    'description'=> esc_html__( 'Legit News Pro Theme Options.', 'legit-news-pro' ),
	    'priority'   => 150,
	) );

	
	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/weather.php';
	
	// homepage sortable
	require get_template_directory() . '/inc/customizer/theme-options/sortable.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// breadcrumb
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'legit_news_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','legit-news-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'legit-news-pro' ),
	    'priority'   => 140,
	) );

			
	// load topbar option
	require get_template_directory() . '/inc/customizer/sections/home-layout.php';
		
	// load topbar option
	require get_template_directory() . '/inc/customizer/sections/topbar.php';

	
	if($options['home_layout'] == 'seventh-design' || $options['home_layout'] == 'eight-design' ){

		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/slider.php';

		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/service.php';
		
		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/about.php';

		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/counter.php';
		
		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/team.php';
		
		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/subscription.php';
		
		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/business/blog.php';

	} else{

		
		if($options['home_layout'] != 'sixth-design'){

			// load Breaking News option
			require get_template_directory() . '/inc/customizer/sections/breaking-news.php';	
		
			// load Hero Post option
			require get_template_directory() . '/inc/customizer/sections/hero-post.php';	
			
			// load must-read option
			require get_template_directory() . '/inc/customizer/sections/must-read.php';
		
			// load trending news option
			require get_template_directory() . '/inc/customizer/sections/trending-news.php';
			
			// load fashion option
			require get_template_directory() . '/inc/customizer/sections/fashion.php';
			
			// load photography option
			require get_template_directory() . '/inc/customizer/sections/photography.php';
			
			// load culture option
			require get_template_directory() . '/inc/customizer/sections/culture.php';
			
			// load Single Column option
			require get_template_directory() . '/inc/customizer/sections/single-column.php';
			
		}else{
					
			// load Hero Post option
			require get_template_directory() . '/inc/customizer/sections/hero-post.php';	
			
			// load must-read option
			require get_template_directory() . '/inc/customizer/sections/must-read.php';
			
			// load Single Column option
			require get_template_directory() . '/inc/customizer/sections/single-column.php';
		}
		
		// load related-post option
		require get_template_directory() . '/inc/customizer/sections/related-post.php';
	}

}
add_action( 'customize_register', 'legit_news_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function legit_news_pro_customize_preview_js() {
	wp_enqueue_script( 'legit-news-pro-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'legit_news_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function legit_news_pro_customize_control_js() {
	// fontawesome
	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome' . legit_news_pro_min() . '.css' );
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . legit_news_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . legit_news_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	wp_enqueue_style( 'legit-news-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . legit_news_pro_min() . '.css' );

	wp_enqueue_script( 'legit-news-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls.js', array(), '1.0', true );
	
	$legit_news_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'legit-news-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'legit-news-pro-customize-controls', 'legit_news_pro_reset_data', $legit_news_pro_reset_data );
}
add_action( 'customize_controls_enqueue_scripts', 'legit_news_pro_customize_control_js' );

if ( !function_exists( 'legit_news_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Legit News Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function legit_news_pro_reset_options() {
		$options = legit_news_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'legit_news_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'legit_news_pro_reset_options' );
