<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 * @return array An array of default values
 */

function legit_news_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$legit_news_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#212121',
		'header_tagline_color'			=> '#212121',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff4443',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'legit-news-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'legit-news-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'legit-news-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'breaking_news,hero_post,must_read,main_post,related_post',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'legit-news-pro' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'						=> false,
		
		// single post theme options
		'single_post_hide_date' 			=> false,
		'single_post_hide_author'			=> false,
		'single_post_hide_category'			=> false,
		'single_post_hide_tags'				=> false,
		'single_post_hide_featured_image'	=> false,
		
		/* Front Page */
		
		// Topbar
		'topbar_section_enable'			=> false,
		'secondary_menu_enable'			=> false,
		'social_menu_enable'			=> false,
		
		//Breaking News
		'breaking_news_section_enable'	=> true,
		'breaking_news_count'			=> 4,
		'breaking_news_content_type'	=> 'post',
		'breaking_news_title'			=> esc_html__('Breaking News', 'legit-news-pro'),
		
		//Hero Post
		'hero_post_section_enable'		=> true,
		'hero_post_count'				=> 3,
		'hero_post_content_type'		=> 'post',
		'hero_post_btn_title' 			=> esc_html__( 'Read more', 'legit-news-pro' ),

		// Hero
		'popular_section_enable'		=> true,
		'popular_content_type'			=> 'category',
		'popular_count'					=> 5,
		
		// Must Read
		'must_read_section_enable'		=> true,
		'must_read_title'				=> esc_html__( 'Must Read Articles', 'legit-news-pro' ),
		'must_read_content_type'		=> 'category',
		'must_read_count'				=> 4,
		
		// Trending News
		'trending_news_section_enable'	=> true,
		'trending_news_title'			=> esc_html__( 'Trending News Articles', 'legit-news-pro' ),
		'trending_news_content_type'	=> 'category',
		'trending_news_count'			=> 4,

		// Fashion
		'fashion_section_enable'		=> true,
		'fashion_title'					=> esc_html__( 'Fashion', 'legit-news-pro' ),
		'fashion_content_type'			=> 'category',
		'fashion_count'					=> 16,
		'fashion_post_per_slide'		=> 6,

		// Photography
		'photography_section_enable'	=> true,
		'photography_title'				=> esc_html__( 'Photography', 'legit-news-pro' ),
		'photography_content_type'		=> 'category',
		'photography_count'				=> 5,

		// Cultural
		'culture_section_enable'			=> true,
		'culture_title'						=> esc_html__( 'CULTURE & TRADITION', 'legit-news-pro' ),
		'culture_content_type'				=> 'category',
		'culture_count'						=> 4,

		// Single Column
		'single_column_section_enable'		=> true,
		'single_column_title'				=> esc_html__( 'Tours & Travel', 'legit-news-pro' ),
		'single_column_content_type'		=> 'category',
		'single_column_count'				=> 4,

		// Related_post
		'related_post_section_enable'		=> true,
		'related_post_title'				=> esc_html__( 'Related News', 'legit-news-pro' ),
		'related_post_content_type'			=> 'category',
		'related_post_count'				=> 4,
		'related_post_column'				=> esc_attr('col-4'),
		'related_post_btn_title' 			=> esc_html__( 'Read more', 'legit-news-pro' ),
		
		//Business about 
		'about_section_enable'				=> true,
		'about_content_type'				=> 'post',
		'about_btn_title'					=> esc_html__( 'Read more', 'legit-news-pro' ),
		
		//Business slider 
		'slider_section_enable'				=> true,
		'slider_autoplay'					=> true,
		'slider_count'						=> 3,
		'slider_content_type'				=> 'category',
		'slider_btn_title'					=> esc_html__( 'Learn Details', 'legit-news-pro' ),
		

		// Business team
		'team_section_enable'				=> true,
		'team_title'						=> esc_html__( 'Meet Our Team', 'legit-news-pro' ),
		'team_content_type'					=> 'category',
		'team_count'						=> 4,

		// Business service
		'service_section_enable'			=> true,
		'service_title'						=> esc_html__( 'Make Successful Business', 'legit-news-pro' ),
		'service_content_type'				=> 'category',
		'service_count'						=> 3,

		// Business blog
		'blog_section_enable'				=> true,
		'blog_title'						=> esc_html__( 'Latest News', 'legit-news-pro' ),
		'blog_content_type'					=> 'recent',
		'blog_count'						=> 3,
		'blog_btn_title'					=> esc_html__( 'Read More', 'legit-news-pro' ),
		
		// Business subscription
		'subscription_section_enable'		=> true,
		'subscription_sub_title'			=> esc_html__( 'Newsletter', 'legit-news-pro' ),
		'subscription_title'				=> esc_html__( 'STAY INFORMED', 'legit-news-pro' ),
		'subscription_bg_image'				=> get_template_directory_uri() .'/assets/uploads/business-subscribe-us.jpg',
		'subscription_btn_title'			=> esc_html__( 'Subscribe Now', 'legit-news-pro' ),
		
		// Business counter
		'counter_section_enable'			=> true,
		'counter_count'						=> 4,
		'counter_image'						=> get_template_directory_uri() .'/assets/uploads/business-counter.jpg',

		//weather
		'weather_section_enable'			=> true,


	);

	$output = apply_filters( 'legit_news_pro_default_theme_options', $legit_news_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}