<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'legit_news_pro_about_section', array(
	'title'             => esc_html__( 'About Us','legit-news-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// About Section enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_about_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );


// About content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_about_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'legit-news-pro' ),
		'page' 		=> esc_html__( 'Page', 'legit-news-pro' ),
	),
) );

// About pages drop down chooser control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_page',
) );

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_about_section',
	'choices'			=> legit_news_pro_page_choices(),
	'active_callback'	=> 'legit_news_pro_is_about_section_content_page_enable',
) ) );

// About posts drop down chooser control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_page',
) );

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_about_section',
	'choices'			=> legit_news_pro_post_choices(),
	'active_callback'	=> 'legit_news_pro_is_about_section_content_post_enable',
) ) );



// about btn title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
	$wp_customize->add_control( 'legit_news_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_about_section',
	'active_callback' 	=> 'legit_news_pro_is_about_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[about_btn_title]', array(
		'selector'            => 'div#about-us-read-more a',
		'settings'            => 'legit_news_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_about_btn_title_partial',
		) );
	}

