<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'legit_news_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','legit-news-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_blog_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );


// blog title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_blog_section',
	'active_callback' 	=> 'legit_news_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[blog_title]', array(
		'selector'            => 'div#blog-header h2',
		'settings'            => 'legit_news_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_blog_title_partial',
    ) );
}

// blog Description setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[blog_description]', array(
	'label'           	=> esc_html__( 'Description', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_blog_section',
	'active_callback' 	=> 'legit_news_pro_is_blog_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[blog_description]', array(
		'selector'            => '#business-latest-posts .business-section-header p',
		'settings'            => 'legit_news_pro_theme_options[blog_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_blog_description_partial',
    ) );
}

// Blog content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_blog_section_enable',
	'choices'			=> array( 
		'recent' 	=> esc_html__( 'Recent', 'legit-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'legit-news-pro' ),
		'page' 		=> esc_html__( 'Page', 'legit-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'legit-news-pro' ),
	),
) );

// Blog post number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_blog_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_blog_section',
	'active_callback'   => 'legit_news_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// Blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_blog_section',
		'choices'			=> legit_news_pro_page_choices(),
		'active_callback'	=> 'legit_news_pro_is_blog_section_content_page_enable',
	) ) );

	// Blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_blog_section',
		'choices'			=> legit_news_pro_post_choices(),
		'active_callback'	=> 'legit_news_pro_is_blog_section_content_post_enable',
	) ) );

endfor;


// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'legit_news_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'legit_news_pro_is_blog_section_content_category_enable'
) ) );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Category_Control( $wp_customize,'legit_news_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'legit_news_pro_is_blog_section_content_recent_enable'
) ) );


// blog btn title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_blog_section',
	'active_callback' 	=> 'legit_news_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[blog_btn_title]', array(
		'selector'            => '#blog-read-more a.more-link',
		'settings'            => 'legit_news_pro_theme_options[blog_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_blog_btn_title_partial',
    ) );
}