<?php
/**
 * Counter Section options
 * 
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'legit_news_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','legit-news-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new legit_news_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_counter_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_image',
	'default'			=> $options['counter_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'legit_news_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'legit-news-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'legit-news-pro' ), 1350, 385 ),
		'section'     		=> 'legit_news_pro_counter_section',
		'active_callback'	=> 'legit_news_pro_is_counter_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_counter_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_counter_section',
	'active_callback'   => 'legit_news_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 4,
		'style' => 'width: 50%;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	
	//Service icon setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control('legit_news_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'legit-news-pro' ), $i ),
		'description'       => sprintf( '%1$s <a href="%2$s" target="_blank">  %3$s </a> </br> %4$s', esc_html__( 'Get the icon name from', 'legit-news-pro' ),esc_url('https://fontawesome.com/v4.7.0/'), esc_html__( 'Font Awesome v4.7.0', 'legit-news-pro' ), esc_html('e.g : fa-bar-chart-o')),
		'section'           => 'legit_news_pro_counter_section',
		'type'				=>'text',
		'active_callback'	=> 'legit_news_pro_is_counter_section_enable',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'legit-news-pro' ), $i ),
		'section'        	=> 'legit_news_pro_counter_section',
		'active_callback' 	=> 'legit_news_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'legit-news-pro' ), $i ),
		'section'        	=> 'legit_news_pro_counter_section',
		'active_callback' 	=> 'legit_news_pro_is_counter_section_enable',
        'type'				=> 'text',
        'input_attrs'		=> array(
            'style' => 'width: 50%;'
            ),
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new legit_news_Pro_Customize_Horizontal_Line( $wp_customize, 'legit_news_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'legit_news_pro_counter_section',
			'active_callback' => 'legit_news_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;



