<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

	// Add Service section
	$wp_customize->add_section( 'legit_news_pro_service_section', array(
		'title'             => esc_html__( 'Services','legit-news-pro' ),
		'description'       => esc_html__( 'Services Section options.', 'legit-news-pro' ),
		'panel'             => 'legit_news_pro_front_page_panel',
	) );

	// Service content enable control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_section_enable]', array(
		'default'			=> 	$options['service_section_enable'],
		'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[service_section_enable]', array(
		'label'             => esc_html__( 'Service Section Enable', 'legit-news-pro' ),
		'section'           => 'legit_news_pro_service_section',
		'on_off_label' 		=> legit_news_pro_switch_options(),
	) ) );

	// service title setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['service_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[service_title]', array(
		'label'           	=> esc_html__( 'Title', 'legit-news-pro' ),
		'section'        	=> 'legit_news_pro_service_section',
		'active_callback' 	=> 'legit_news_pro_is_service_section_enable',
		'type'				=> 'text',
	) );

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[service_title]', array(
			'selector'            => '#business-services .business-section-header h2',
			'settings'            => 'legit_news_pro_theme_options[service_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'legit_news_pro_service_title_partial',
		) );
	}

	// service description setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_description]', array(
		'sanitize_callback' => 'sanitize_textarea_field',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'legit_news_pro_theme_options[service_description]', array(
		'label'           	=> esc_html__( 'Description', 'legit-news-pro' ),
		'section'        	=> 'legit_news_pro_service_section',
		'active_callback' 	=> 'legit_news_pro_is_service_section_enable',
		'type'				=> 'textarea',
	) );

		// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[service_description]', array(
			'selector'            => '#business-services .business-section-header p',
			'settings'            => 'legit_news_pro_theme_options[service_description]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'legit_news_pro_service_description_partial',
		) );
	}



// Service count number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_service_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_service_section',
	'active_callback'   => 'legit_news_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'legit_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'legit_news_pro_is_service_section_enable',
	'choices'			=> array( 
		'category' 	=> esc_html__( 'Category', 'legit-news-pro' ),
		'page' 		=> esc_html__( 'Page', 'legit-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'legit-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_service_section',
		'choices'			=> legit_news_pro_page_choices(),
		'active_callback'	=> 'legit_news_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'legit_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Legit_News_Pro_Dropdown_Chooser( $wp_customize, 'legit_news_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'legit-news-pro' ), $i ),
		'section'           => 'legit_news_pro_service_section',
		'choices'			=> legit_news_pro_post_choices(),
		'active_callback'	=> 'legit_news_pro_is_service_section_content_post_enable',
	) ) );


	//Service icon setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control('legit_news_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'legit-news-pro' ), $i ),
		'description'       => sprintf( '%1$s <a href="%2$s" target="_blank">  %3$s </a> </br> %4$s', esc_html__( 'Get the icon name from', 'legit-news-pro' ),esc_url('https://fontawesome.com/v4.7.0/'), esc_html__( 'Font Awesome v4.7.0', 'legit-news-pro' ), esc_html('e.g : fa-bar-chart-o')),
		'section'           => 'legit_news_pro_service_section',
		'type'				=>'text',
		'active_callback'	=> 'legit_news_pro_is_service_section_enable',
	) );

	// service hr setting and control
	$wp_customize->add_setting( 'legit_news_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Legit_News_Pro_Customize_Horizontal_Line( $wp_customize, 'legit_news_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'legit_news_pro_service_section',
			'active_callback' => 'legit_news_pro_is_service_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'legit_news_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'legit_news_pro_is_service_section_content_category_enable'
) ) );

