<?php
/**
 * Trending News Section options
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

// Add Trending News section
$wp_customize->add_section( 'legit_news_pro_trending_news_section', array(
	'title'             => esc_html__( 'Trending News','legit-news-pro' ),
	'description'       => esc_html__( 'Trending News Section options.', 'legit-news-pro' ),
	'panel'             => 'legit_news_pro_front_page_panel',
) );

// Trending News content enable control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[trending_news_section_enable]', array(
	'default'			=> 	$options['trending_news_section_enable'],
	'sanitize_callback' => 'legit_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Legit_News_Pro_Switch_Control( $wp_customize, 'legit_news_pro_theme_options[trending_news_section_enable]', array(
	'label'             => esc_html__( 'Trending News Section Enable', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_trending_news_section',
	'on_off_label' 		=> legit_news_pro_switch_options(),
) ) );

// trending_news title setting and control
$wp_customize->add_setting( 'legit_news_pro_theme_options[trending_news_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['trending_news_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[trending_news_title]', array(
	'label'           	=> esc_html__( 'Title', 'legit-news-pro' ),
	'section'        	=> 'legit_news_pro_trending_news_section',
	'active_callback' 	=> 'legit_news_pro_is_trending_news_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'legit_news_pro_theme_options[trending_news_title]', array(
		'selector'            => '#trending-news div.world-news-wrapper div div h2.section-title',
		'settings'            => 'legit_news_pro_theme_options[trending_news_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'legit_news_pro_trending_news_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'legit_news_pro_theme_options[trending_news_count]', array(
	'default'          	=> $options['trending_news_count'],
	'sanitize_callback' => 'legit_news_pro_sanitize_number_range',
	'validate_callback' => 'legit_news_pro_validate_trending_news_count',
) );

$wp_customize->add_control( 'legit_news_pro_theme_options[trending_news_count]', array(
	'label'             => esc_html__( 'Number of page/post per category', 'legit-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_trending_news_section',
	'active_callback'   => 'legit_news_pro_is_trending_news_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
) );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'legit_news_pro_theme_options[trending_news_content_category]', array(
	'sanitize_callback' => 'legit_news_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Legit_News_Pro_Dropdown_Category_Control( $wp_customize,'legit_news_pro_theme_options[trending_news_content_category]', array(
	'label'             => esc_html__( 'Select Multiple Category', 'legit-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'legit-news-pro' ),
	'section'           => 'legit_news_pro_trending_news_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'legit_news_pro_is_trending_news_section_enable'
) ) );
