<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_about_section() {
        $options = legit_news_pro_get_theme_options();
        
        // Check if About is enabled on frontpage
        $about_enable = apply_filters( 'legit_news_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        $section_details = array();

        // Get About section details
        $section_details = apply_filters( 'legit_news_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render About default design section .
        legit_news_pro_render_about_section( $section_details );

    }
endif;

if ( ! function_exists( 'legit_news_pro_get_about_section_details' ) ) :
    /**
    * About section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input about section details.
    */
    function legit_news_pro_get_about_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = legit_news_pro_trim_content( 35 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// About section content details.
add_filter( 'legit_news_pro_filter_about_section_details', 'legit_news_pro_get_about_section_details' );


if ( ! function_exists( 'legit_news_pro_render_about_section' ) ) :
  /**
   * Start About section
   *
   * @return string About content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_about_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();
        $about_btn_title = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Read More', 'legit-news-pro' );


        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>

        <div id="business-about-us" class="relative page-section">
            <div class="wrapper">
                <article class="has-post-thumbnail">
                    <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']);?>');">
                        <a href="#" class="post-thumbnail-link"></a>
                    </div><!-- .featured-image -->

                    <div class="entry-container">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                        </div><!-- .entry-content -->

                        <?php if(!empty($about_btn_title)): ?>
                        <div class="business-read-more">
                            <a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($about_btn_title); ?></a>
                        <?php endif; ?>

                        </div><!-- .business-read-more -->
                    </div><!-- .entry-container -->
                </article>
            </div><!-- .wrapper -->
        </div><!-- #business-about-us -->

        <?php 
    }
endif;
