<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_slider_section() {
        $options = legit_news_pro_get_theme_options();
        
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'legit_news_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_slider_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Default slider section now.
        legit_news_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input slider section details.
    */
    function legit_news_pro_get_slider_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        
        $slider_content_type  = $options['slider_content_type']; // Slider Content type.
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3; //Slider Post Count
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

			
            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = legit_news_pro_trim_content( 15 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// slider section content details.
add_filter( 'legit_news_pro_filter_slider_section_details', 'legit_news_pro_get_slider_section_details' );


if ( ! function_exists( 'legit_news_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_slider_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();

        $btn_title          = ! empty( $options['slider_btn_title'] ) ? $options['slider_btn_title'] : esc_html__( 'Learn Details', 'legit-news-pro' );
        $slider_autoplay    = ($options['slider_autoplay'] == true ) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="business-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay":  <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>
            <?php foreach ($content_details as $content) : ?>
                
                <article style="background-image:url('<?php echo esc_url($content['image']); ?>');">
                    <div class="overlay"></div>
                    <div class="business-slider-wrapper">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo esc_html($content['excerpt']); ?></p>
                        </div><!-- .entry-content-->

                        <?php if(!empty($btn_title)): ?>
                            <div class="business-read-more">
                                <a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($btn_title); ?></a>
                            </div><!-- .business-read-more -->
                        <?php endif; ?>
                    </div><!-- .business-slider-wrapper -->
                </article>
                <?php endforeach; ?>

            </div><!-- #featured-slider -->
    <?php }
endif;  

