<?php
/**
 * Fashion  section
 *
 * This is the template for the content of fashion section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_fashion_section' ) ) :
    /**
    * Add fashion section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_fashion_section() {
        $options = legit_news_pro_get_theme_options();
        // Check if fashion is enabled on frontpage
        $fashion_enable = apply_filters( 'legit_news_pro_section_status', true, 'fashion_section_enable' );

        if ( true !== $fashion_enable ) {
            return false;
        }

        $home_layout = $options['home_layout'];
        // Get fashion section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_fashion_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        if($home_layout == 'second-design'){
            legit_news_pro_render_fashion_second_design_section( $section_details );
        }else{
            // Render fashion section now.
            legit_news_pro_render_fashion_section( $section_details );
        }
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_fashion_section_details' ) ) :
    /**
    * fashion section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input fashion section details.
    */
    function legit_news_pro_get_fashion_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        // Content type.
        $fashion_content_type  = $options['fashion_content_type'];
        $fashion_count = ! empty( $options['fashion_count'] ) ? $options['fashion_count'] : 16;
        
        $content = array();
        switch ( $fashion_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $fashion_count; $i++ ) {
                    if ( ! empty( $options['fashion_content_page_' . $i] ) )
                        $page_ids[] = $options['fashion_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $fashion_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $fashion_count; $i++ ) {
                    if ( ! empty( $options['fashion_content_post_' . $i] ) )
                        $post_ids[] = $options['fashion_content_post_' . $i];
                }
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $fashion_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['fashion_content_category'] ) ? $options['fashion_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $fashion_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() .'/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// fashion section content details.
add_filter( 'legit_news_pro_filter_fashion_section_details', 'legit_news_pro_get_fashion_section_details' );


if ( ! function_exists( 'legit_news_pro_render_fashion_section' ) ) :
  /**
   * Start fashion section
   *
   * @return string fashion content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_fashion_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();
        $post_per_slide   = $options['fashion_post_per_slide'];
        $fashion_count = ! empty( $options['fashion_count'] ) ? $options['fashion_count'] : 16;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="fashion-slider">
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html($options['fashion_title']); ?></h2>
            </div>

            <div class="posts-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                <?php 
                $per_slide_content_details = array_chunk($content_details, $post_per_slide);
                foreach($per_slide_content_details as $content): ?>
                <div class="fashion-wrapper">
                    <?php $slide_details = array_chunk($content, ceil(count($content) / 2)); 
                    foreach($slide_details as $posts): ?>
                        <div class="hentry">
                        <?php foreach($posts as $key=>$post): ?>

                            <article>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                <?php if($key==0) echo '<div class="overlay"></div>';?>
                                </div>

                                <div class="entry-container">
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                            <?php the_category( '', '', $post['id'] ); ?>
                                        </span><!-- .cat-links -->      
                                    </div><!-- .entry-meta -->
                                <div class="footer-meta">
                                <?php 
                                    legit_news_pro_posted_on( $post['id'] );
                                    echo legit_news_pro_author($post['id']); ?>
                                </div><!-- .footer-meta -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($post['url']); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                </header>
                                </div><!-- .entry-container -->
                            </article>

                            <?php endforeach;?>
                        </div><!-- .hentry -->
                    <?php endforeach;?>
                </div><!-- .fashion-wrapper -->
                <?php endforeach;?>
            </div><!-- .posts-slider -->
        </div><!-- #fashion-slider -->
    <?php }
endif;

if ( ! function_exists( 'legit_news_pro_render_fashion_second_design_section' ) ) :
  /**
   * Start fashion section
   *
   * @return string fashion content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_fashion_second_design_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="read">
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html($options['fashion_title']); ?></h2>
            </div>

            <div class="posts-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
            <?php foreach($content_details as $post): ?>

                <article style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                    <div class="entry-meta">
                        <span class="cat-links">
                            <?php the_category( '', '', $post['id'] ); ?>
                        </span><!-- .cat-links -->      
                    </div><!-- .entry-meta -->

                    <div class="entry-container">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($post['url']); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                        </header>

                        <div class="footer-meta">
                        <?php 
                            legit_news_pro_posted_on( $post['id'] );
                            echo legit_news_pro_author($post['id']); ?>
                        </div><!-- .footer-meta -->

                    </div><!-- .entry-container -->
                </article>

                <?php endforeach;?>

            </div><!-- .featured-slider -->
        </div><!-- #read -->
    <?php }
endif;
