<?php
/**
 * Must Read  section
 *
 * This is the template for the content of trending_news section
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */
if ( ! function_exists( 'legit_news_pro_add_trending_news_section' ) ) :
    /**
    * Add trending_news section
    *
    *@since Legit News Pro 1.0.0
    */
    function legit_news_pro_add_trending_news_section() {
        $options = legit_news_pro_get_theme_options();
        // Check if trending_news is enabled on frontpage
        $trending_news_enable = apply_filters( 'legit_news_pro_section_status', true, 'trending_news_section_enable' );

        if ( true !== $trending_news_enable ) {
            return false;
        }
        // Get trending_news section details
        $section_details = array();
        $section_details = apply_filters( 'legit_news_pro_filter_trending_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

              
        switch ( $options['home_layout'] ) {
            case 'default-design':
                // Render trending_news section now.
                legit_news_pro_render_trending_news_section( $section_details );
                break;
            
            case 'second-design':
                // Render trending_news section now.
                legit_news_pro_render_second_trending_news_section( $section_details );
                break;
            
            default:
                // Render trending_news section now.
                legit_news_pro_render_trending_news_section( $section_details );
        }

        
    }
endif;

if ( ! function_exists( 'legit_news_pro_get_trending_news_section_details' ) ) :
    /**
    * trending_news section details.
    *
    * @since Legit News Pro 1.0.0
    * @param array $input trending_news section details.
    */
    function legit_news_pro_get_trending_news_section_details( $input ) {
        $options = legit_news_pro_get_theme_options();

        // Content type.
        $trending_news_content_type  = $options['trending_news_content_type'];
        $trending_news_count = ! empty( $options['trending_news_count'] ) ? $options['trending_news_count'] : 5;
        
        $content = array();

        $cat_ids = ! empty( $options['trending_news_content_category'] ) ? $options['trending_news_content_category'] : '';
        $cat_slugs = legit_news_pro_convert_cat_id_to_slug($cat_ids);

        if ( empty( $cat_ids ) )
            return;

        $content['all'] = array();
        
        foreach ( $cat_slugs as $slug ) :
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => absint( $trending_news_count ),
                'category_name'         =>  $slug,
                'ignore_sticky_posts'   => true,
            );
            // Run The Loop.
            $query = new WP_Query( $args );
            $content[$slug] = array();
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $post = array();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = legit_news_pro_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() .'/assets/uploads/no-featured-image-590x650.jpg';


                    // Push to the main array.
                    array_push( $content['all'], $page_post );
                    array_push( $content[$slug], $page_post );
                endwhile;


            endif;
            wp_reset_postdata();
        endforeach;  
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// trending_news section content details.
add_filter( 'legit_news_pro_filter_trending_news_section_details', 'legit_news_pro_get_trending_news_section_details' );


if ( ! function_exists( 'legit_news_pro_render_trending_news_section' ) ) :
  /**
   * Start trending_news section
   *
   * @return string trending_news content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_trending_news_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();


        if ( empty( $content_details ) ) {
            return;

        };
        $cat_ids = ! empty( $options['trending_news_content_category'] ) ? $options['trending_news_content_category'] : ''; 
        $cat_slugs = legit_news_pro_convert_cat_id_to_slug($cat_ids); ?>

            <div id="trending-news">
                    <div class="section-header-wrapper">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html($options['trending_news_title']); ?></h2>
                        </div><!-- .section-header -->

                        <div class="pull-wrapper">
                            <div class="pull">
                                <span>
                                <?php esc_html_e('All', 'legit-news-pro');
                                 echo legit_news_pro_get_svg( array( 'icon' => 'down' ) ); ?>
                                </span>
                            </div>
                            <ul id="ajax-filter" class="tabs">
                                <li data-tab="all" class="active"><a href="#"><?php esc_html_e('All', 'legit-news-pro')?></a></li>
                                <?php foreach($cat_slugs as $slug):
                                    $cat = get_category_by_slug($slug);
                                    echo '<li data-tab="'.esc_attr($cat->slug).'"><a href="#">'.esc_html($cat->name).'</a></li>';
                                endforeach; ?>
                                
                            </ul><!-- #ajax-filter -->
                        </div>
                    </div><!-- .section-header-wrapper -->

                <div class="tab clear">

                <?php
                    array_unshift($cat_slugs, 'all') ;
                    foreach($cat_slugs as $slug): 
                        $slug = ($slug == 'all') ? 'all' : get_category_by_slug($slug)->slug; ?>
                        
                        <div id="<?php echo esc_attr( $slug ); ?>" class="tab-content <?php echo ($slug == 'all') ? 'active' : ''; ?>">

                        <?php foreach($content_details[$slug] as $key=>$post):
                            if($slug == 'all' && $key>4) continue; ?>

                            <article class="hentry">
                                <div class="trending-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                        <a href="<?php echo esc_url( $post['url'] ); ?>" class="post-thumbnail-link"></a>
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                                <?php the_category( '', '', $post['id'] ); ?>
                                            </span><!-- .cat-links -->      
                                        </div>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="footer-meta">
                                        <?php 
                                            legit_news_pro_posted_on( $post['id'] );
                                            echo legit_news_pro_author($post['id']); ?>
                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post($post['excerpt']); ?></p>
                                        </div>
                                    </div><!-- .entry-container -->
                                </div>
                            </article>
                            <?php endforeach; ?>
                            
                        </div>
                    <?php endforeach; ?>

                </div>
            </div><!-- #trending-news -->
    <?php }
endif;


if ( ! function_exists( 'legit_news_pro_rendersecond_trending_news_section' ) ) :
  /**
   * Start trending_news section
   *
   * @return string trending_news content
   * @since Legit News Pro 1.0.0
   *
   */
   function legit_news_pro_render_second_trending_news_section( $content_details = array() ) {
        $options = legit_news_pro_get_theme_options();


        if ( empty( $content_details ) ) {
            return;

        };
        $cat_ids = ! empty( $options['trending_news_content_category'] ) ? $options['trending_news_content_category'] : ''; 
        $cat_slugs = legit_news_pro_convert_cat_id_to_slug($cat_ids); ?>

                <div id="news">
                    <div class="section-header-wrapper">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html($options['trending_news_title']); ?></h2>
                        </div><!-- .section-header -->

                        <div class="pull-wrapper">
                            <div class="pull">
                                <span>
                                <?php esc_html_e('All', 'legit-news-pro');
                                 echo legit_news_pro_get_svg( array( 'icon' => 'down' ) ); ?>
                                </span>
                            </div>
                            <ul id="ajax-filter" class="tabs">
                                <li data-tab="all" class="active"><a href="#"><?php esc_html_e('All', 'legit-news-pro')?></a></li>
                                <?php foreach($cat_slugs as $slug):
                                    $cat = get_category_by_slug($slug);
                                    echo '<li data-tab="'.esc_attr($cat->slug).'"><a href="#">'.esc_html($cat->name).'</a></li>';
                                endforeach; ?>
                                
                            </ul><!-- #ajax-filter -->
                        </div>
                    </div><!-- .section-header-wrapper -->

                <div class="tab clear">

                <?php
                    array_unshift($cat_slugs, 'all') ;
                    foreach($cat_slugs as $slug): 
                        $slug = ($slug == 'all') ? 'all' : get_category_by_slug($slug)->slug; ?>
                        
                        <div id="<?php echo esc_attr( $slug ); ?>" class="tab-content <?php echo ($slug == 'all') ? 'active' : ''; ?>">
                            <div class="fashion-wrapper">
                                <?php
                                $posts = array_chunk($content_details[$slug], 4); ?>
                            <div class="hentry">
                                <?php foreach($posts[0] as $key=>$post):
                                    if($slug == 'all' && $key>3) continue; 
                                    ?>
                                        <article>
                                            <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                                <div class="entry-meta">
                                                    <span class="cat-links">
                                                        <?php the_category( '', '', $post['id'] ); ?>
                                                    </span><!-- .cat-links -->      
                                                </div>
                                            </div><!-- .featured-image -->

                                            <div class="entry-container">
                                                <div class="footer-meta">
                                                <?php 
                                                    legit_news_pro_posted_on( $post['id'] );
                                                    echo legit_news_pro_author($post['id']); ?>
                                                </div><!-- .entry-meta -->

                                                <header class="entry-header">
                                                    <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                                </header>

                                            </div><!-- .entry-container -->
                                        </article>

                                    <?php endforeach; ?>
                                </div><!-- .hentry -->
                            <?php if(!empty($posts[1])): ?>
                                <div class="hentry">
                                    <?php foreach($posts[1] as $key=>$post):
                                        if($slug == 'all' && $key>3) continue; 
                                        ?>
                                            <article>
                                                <div class="featured-image" style="background-image: url('<?php echo esc_url($post['image']); ?>');">
                                                    <div class="entry-meta">
                                                        <span class="cat-links">
                                                            <?php the_category( '', '', $post['id'] ); ?>
                                                        </span><!-- .cat-links -->      
                                                    </div>
                                                </div><!-- .featured-image -->

                                                <div class="entry-container">
                                                    <div class="footer-meta">
                                                    <?php 
                                                        legit_news_pro_posted_on( $post['id'] );
                                                        echo legit_news_pro_author($post['id']); ?>
                                                    </div><!-- .entry-meta -->

                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php echo esc_url( $post['url'] ); ?>"><?php echo esc_html($post['title']); ?></a></h2>
                                                    </header>

                                                </div><!-- .entry-container -->
                                            </article>

                                        <?php endforeach; ?>
                                    </div><!-- .hentry -->
                                <?php endif; ?>
                            </div><!-- .fashion-wrapper -->
                        </div><!-- .tab content -->
                    <?php endforeach; ?>

                </div><!-- .tab clear -->
            </div><!-- #trending-news -->
    <?php }
endif;
