<?php
/**
 * Legit News Pro meta inclusion
 *
 * This is the template that includes all custom meta of Legit News Pro
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

if( ! function_exists( 'legit_news_pro_get_post_views' ) ): 
	/**
	*
 	* Get any post views count
	*
	* @since Legit News Pro 1.0.0
	*
	* @param int $post_id Post id of current post.
 	* @return string String with views count
	*/
	function legit_news_pro_get_post_views( $post_id ){
		//Set the name of the meta field.
	    $count_key = 'post_views_count';

		//Get value of the meta field
	    $count = get_post_meta($post_id, $count_key, true);

		//If meta field is empty
	    if( $count=='' ){
			//Delete all custom fields with the specified key from the specified post. 
	        delete_post_meta( $post_id, $count_key );

			//Add a custom (meta) field (Name/value)to the specified post.
	        add_post_meta( $post_id, $count_key, '0' );

	        return "0 View";
	    }
	    return $count.' Views';
	}
endif;

if( ! function_exists( 'legit_news_pro_set_post_views' ) ): 
	/**
	*
 	* Set any post views
	*
	* @since Legit News Pro 1.0.0
	*
	* @param int $post_id Post id of current post.
 	* @return string String with views count
	*/
	function legit_news_pro_set_post_views($post_id) {
		//Set the name of the meta field.
	    $count_key = 'post_views_count';

		//Get value of the meta field
		$count = legit_news_pro_get_post_views($post_id);
		//If meta field is empty
	    if( $count == '' ){
			$count = 0;

			//Delete all custom fields with the specified key from the specified post. 
	        delete_post_meta( $post_id, $count_key );
	        
			//Add a custom (meta) field (Name/value)to the specified post.
	        add_post_meta( $post_id, $count_key, 0);
	    }else{
	        $count = absint($count) + 1;
	        update_post_meta( $post_id, $count_key, $count );
		}
		
	}
endif;


if( ! function_exists( 'legit_news_pro_track_post_views' ) ): 
	/**
	*
 	* Track if single page is loaded
	*
	* @since Legit News Pro 1.0.0
	*
	* @param int $post_id Post id of current post.
 	* @return string String with views count
	*/
	function legit_news_pro_track_post_views ( $post_id ) {
	    if ( ! is_single() ) 
	    	return;
	    if ( empty ( $post_id) ) {
	        global $post;
	        $post_id = $post->ID;    
	    }
	    legit_news_pro_set_post_views( $post_id );
	}
endif;
add_action( 'wp_head', 'legit_news_pro_track_post_views');
