<?php
/**
 * Popular Post Widget
 *
 * @package Theme Palace
 * @subpackage Legit News Pro
 * @since Legit News Pro 1.0.0
 */

if ( ! class_exists( 'Legit_News_Pro_Popular_Post' ) ) :

     
    class Legit_News_Pro_Popular_Post extends WP_Widget {
        /**
         * Sets up the widgets name etc
         */
        public function __construct() {
            $tp_widget_popular_post = array(
                'classname'   => 'widget_recent_news',
                'description' => esc_html__( 'Retrive top viewed posts.', 'legit-news-pro' ),
            );
            parent::__construct( 'legit_news_pro_popular_post', esc_html__( 'TP : Popular Posts', 'legit-news-pro' ), $tp_widget_popular_post );
        }

        /**
         * Outputs the content of the widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget( $args, $instance ) {
            // outputs the content of the widget
            if ( ! isset( $args['widget_id'] ) ) {
                $args['widget_id'] = $this->id;
            }

            $title  = ( ! empty( $instance['title'] ) ) ? ( $instance['title'] ) : '';
            $title  = apply_filters( 'widget_title', $title, $instance, $this->id_base );
            $post_number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
            $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;
            
            echo $args['before_widget'];
                if ( ! empty( $title ) ) {
                    echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
                }
            $popular_args = new WP_Query( apply_filters( 'widget_posts_args', array(
                'post_type'      => 'post',
                'posts_per_page' => $post_number,
                'orderby'        => 'meta_value_num',
                'meta_key'        => 'post_views_count',
                'order'          => 'DESC',
                'ignore_sticky_posts' => true
                ) ) );

            if ($popular_args->have_posts()) :
            ?>
            <ul >
            <?php while ( $popular_args->have_posts() ) : $popular_args->the_post();?>
                <li class="has-post-thumbnail">
                    <?php if( has_post_thumbnail() ) : // check if post has thumbmnail ?> 
                            <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'thumbnail', array( 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
                    <?php else : ?>
                        <a href="<?php the_permalink(); ?>">
                            <img src="<?php echo esc_url( get_template_directory_uri() .'/assets/uploads/no-featured-image-150x150.jpg' ); ?>" alt="<?php the_title_attribute(); ?>">
                        </a>
                    <?php endif; ?>

                    <div class="entry-container">
                    
                        <?php if($show_date) legit_news_pro_posted_on( get_the_ID() );  ?>

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php the_permalink( ); ?>"><?php the_title(); ?></a></h2>
                        </header>

                    </div>
                </li>
            <?php endwhile; 
            wp_reset_postdata();
            ?>
            </ul>
            <?php
            endif;
            echo $args['after_widget'];
        }

        /**
         * Outputs the options form on admin
         *
         * @param array $instance The widget options
         */
        public function form( $instance ) {
            $title            = isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Popular', 'legit-news-pro' );
            $post_number      = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
            $excerpt_value    = isset( $instance['excerpt'] ) ? absint( $instance['excerpt'] ) : 3;
            $show_date        = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
            
           ?>

           <p>
               <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'legit-news-pro' ); ?></label>
               <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
           </p>

           <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'legit-news-pro' ); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="7" value="<?php echo absint( $post_number ); ?>" size="3" />
           </p>

           <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php _e( 'Show Date:', 'legit-news-pro' ); ?></label>
            <input class="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'show_date') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_date') ); ?>" type="checkbox" value="show_date" <?php checked( $show_date ); ?>/>
            </p>

           <?php
        }

        /**
        * Processing widget options on save
        *
        * @param array $new_instance The new options
        * @param array $old_instance The previous options
        */
        public function update( $new_instance, $old_instance ) {
            // processes widget options to be saved
            $instance           = $old_instance;
            $instance['title']  = sanitize_text_field( $new_instance['title'] );
            $instance['number'] = absint( $new_instance['number'] );
            $instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;

            return $instance;
        }
    }
endif;
